<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Form Recipients /////////////////////////
// Buttons:
define('FORM_RECIPIENTS_HEADING', "Змінити форму Одержувачі");
define('FORM_RECIPIENTS_EDIT_FORM_RECIPIENTS_BTN', "Змінити форму Одержувачі");
// Console Text:
define('FORM_RECIPIENTS_FORM_PAGE', "форма сторінки");
define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Ви можете встановити більш одного одержувача, розділяючи листи з запитом.");
// Popup Messages:
define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Збереження одержувача ...");
define('VIEW_FORM_TABLES_HEADING', "Переглянути таблиці форм");
define('VIEW_FORM_TABLES_BTN', "Переглянути таблиці форм");
define('VIEW_FORM_TABLES_SELECT_TABLE', "Виберіть таблиці для перегляду");
define('VIEW_FORM_TABLES_FILTER_READ', "Фільтр прочитати повідомлення");
?>